@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -295,6 +295,18 @@ public:
     virtual Lease6Ptr getLease6(Lease::Type type,
                                 const isc::asiolink::IOAddress& addr) const override;
 
+    /// @brief Returns existing IPv6 leases for specified hardware address.
+    ///
+    /// Although in the usual case there will be only one lease, for mobile
+    /// clients or clients with multiple static/fixed/reserved leases there
+    /// can be more than one. Thus return type is a container, not a single
+    /// pointer.
+    ///
+    /// @param hwaddr hardware address of the client
+    ///
+    /// @return lease collection
+    virtual Lease6Collection getLease6(const isc::dhcp::HWAddr& hwaddr) const override;
+
     /// @brief Returns existing IPv6 lease for a given DUID + IA + lease type
     /// combination
     ///
@@ -666,6 +678,13 @@ private:
     Lease6Ptr getLease6Internal(Lease::Type type,
                                 const isc::asiolink::IOAddress& addr) const;
 
+    /// @brief Gets existing IPv6 leases for specified hardware address.
+    ///
+    /// @param hwaddr hardware address of the client
+    /// @param collection lease collection
+    void getLease6Internal(const isc::dhcp::HWAddr& hwaddr,
+                           Lease6Collection& collection) const;
+
     /// @brief Returns existing IPv6 lease of any type for a given IPv6 address.
     ///
     /// @param addr An address of the searched lease.
@@ -992,7 +1011,9 @@ public:
     /// @brief Returns default path to the lease file.
     ///
     /// @param u Universe (V4 or V6).
-    std::string getDefaultLeaseFilePath(Universe u) const;
+    /// @param filename optional filename to use.
+    std::string getDefaultLeaseFilePath(Universe u,
+                                        const std::string filename = "") const;
 
     /// @brief Returns an absolute path to the lease file.
     ///
